==> react-molecule-photo-uploader-2.15.0.tgz: package/lib/InitialState/index.js <==
import PropTypes from 'prop-types';
import Button, { atomButtonShapes } from '@s-ui/react-atom-button';
import AtomIcon, { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { INITIAL_STATE_CLASS_NAME, ALTERNATIVE_ACTION_TEXT, BUTTON_COLOR, BUTTON_DESIGN, BUTTON_SIZE, ICON_INITIAL_STATE_CLASS_NAME, TEXT_STATE_CLASS_NAME, TEXT_STATE_TEXT_CLASS_NAME, TEXT_STATE_DIVIDER_CLASS_NAME, BUTTON_STATE_CLASS_NAME } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var InitialState = function InitialState(_ref) {
  var _ref$buttonDesign = _ref.buttonDesign,
      buttonDesign = _ref$buttonDesign === void 0 ? BUTTON_DESIGN : _ref$buttonDesign,
      _ref$buttonColor = _ref.buttonColor,
      buttonColor = _ref$buttonColor === void 0 ? BUTTON_COLOR : _ref$buttonColor,
      buttonText = _ref.buttonText,
      buttonShape = _ref.buttonShape,
      _ref$buttonSize = _ref.buttonSize,
      buttonSize = _ref$buttonSize === void 0 ? BUTTON_SIZE : _ref$buttonSize,
      icon = _ref.icon,
      text = _ref.text,
      _ref$dividerText = _ref.dividerText,
      dividerText = _ref$dividerText === void 0 ? ALTERNATIVE_ACTION_TEXT : _ref$dividerText;
  return /*#__PURE__*/_jsxs("div", {
    className: INITIAL_STATE_CLASS_NAME,
    children: [/*#__PURE__*/_jsx("div", {
      className: ICON_INITIAL_STATE_CLASS_NAME,
      children: /*#__PURE__*/_jsx(AtomIcon, {
        size: ATOM_ICON_SIZES.extraLarge,
        children: icon
      })
    }), /*#__PURE__*/_jsxs("div", {
      className: TEXT_STATE_CLASS_NAME,
      children: [/*#__PURE__*/_jsx("span", {
        className: TEXT_STATE_TEXT_CLASS_NAME,
        children: text
      }), /*#__PURE__*/_jsx("span", {
        className: TEXT_STATE_DIVIDER_CLASS_NAME,
        children: dividerText
      })]
    }), /*#__PURE__*/_jsx("div", {
      className: BUTTON_STATE_CLASS_NAME,
      children: /*#__PURE__*/_jsx(Button, {
        color: buttonColor,
        design: buttonDesign,
        isButton: true,
        shape: buttonShape,
        size: buttonSize,
        children: buttonText
      })
    })]
  });
};

InitialState.displayName = 'InitialState';
export default InitialState;

==> react-molecule-photo-uploader-2.17.0.tgz: package/lib/InitialState/index.js <==
import cx from 'classnames';
import PropTypes from 'prop-types';
import Button, { atomButtonShapes } from '@s-ui/react-atom-button';
import AtomIcon, { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { INITIAL_STATE_CLASS_NAME, ALTERNATIVE_ACTION_TEXT, BUTTON_COLOR, BUTTON_DESIGN, BUTTON_SIZE, ICON_INITIAL_STATE_CLASS_NAME, TEXT_STATE_CLASS_NAME, TEXT_STATE_TEXT_CLASS_NAME, TEXT_STATE_DIVIDER_CLASS_NAME, BUTTON_STATE_CLASS_NAME } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var InitialState = function InitialState(_ref) {
  var _ref$buttonDesign = _ref.buttonDesign,
      buttonDesign = _ref$buttonDesign === void 0 ? BUTTON_DESIGN : _ref$buttonDesign,
      _ref$buttonColor = _ref.buttonColor,
      buttonColor = _ref$buttonColor === void 0 ? BUTTON_COLOR : _ref$buttonColor,
      buttonText = _ref.buttonText,
      buttonShape = _ref.buttonShape,
      _ref$buttonSize = _ref.buttonSize,
      buttonSize = _ref$buttonSize === void 0 ? BUTTON_SIZE : _ref$buttonSize,
      icon = _ref.icon,
      text = _ref.text,
      _ref$dividerText = _ref.dividerText,
      dividerText = _ref$dividerText === void 0 ? ALTERNATIVE_ACTION_TEXT : _ref$dividerText;
  return /*#__PURE__*/_jsxs("div", {
    className: INITIAL_STATE_CLASS_NAME,
    children: [/*#__PURE__*/_jsx("div", {
      className: ICON_INITIAL_STATE_CLASS_NAME,
      children: /*#__PURE__*/_jsx(AtomIcon, {
        size: ATOM_ICON_SIZES.extraLarge,
        children: icon
      })
    }), /*#__PURE__*/_jsxs("div", {
      className: TEXT_STATE_CLASS_NAME,
      children: [/*#__PURE__*/_jsx("span", {
        className: cx(TEXT_STATE_TEXT_CLASS_NAME, {
          isSpaced: !dividerText
        }),
        children: text
      }), dividerText ? /*#__PURE__*/_jsx("span", {
        className: TEXT_STATE_DIVIDER_CLASS_NAME,
        children: dividerText
      }) : null]
    }), /*#__PURE__*/_jsx("div", {
      className: BUTTON_STATE_CLASS_NAME,
      children: /*#__PURE__*/_jsx(Button, {
        color: buttonColor,
        design: buttonDesign,
        isButton: true,
        shape: buttonShape,
        size: buttonSize,
        children: buttonText
      })
    })]
  });
};

InitialState.displayName = 'InitialState';
export default InitialState;
